@@ -50,11 +50,11 @@ Create TYPE "TransactionErrorCode" AS ENUM (
     'InvalidWritableAccount',
     'WouldExceedMaxAccountDataCostLimit',
     'TooManyAccountLocks',
-    'AddressLookupError'
     'AddressLookupTableNotFound',
     'InvalidAddressLookupTableOwner',
     'InvalidAddressLookupTableData',
-    'InvalidAddressLookupTableIndex'
+    'InvalidAddressLookupTableIndex',
+    'InvalidRentPayingAccount'
 );
 
 CREATE TYPE "TransactionError" AS (
